@@ -1,4 +1,4 @@
-import utils.utils as utils
+import defichainUtils.utils.utils as utils
 
 def decodeCustomTx(hex):
     '''
